edam package
============

Module contents
---------------

.. automodule:: edam
:members:
        :undoc-members:
        :show-inheritance:

.. automodule:: edam.reader.template_reader.models
:members:
        :undoc-members:
        :show-inheritance:

.. automodule:: edam.reader.template_reader.TemplateReader
:members:
        :undoc-members:
        :show-inheritance:

.. automodule:: edam.reader.template_reader.utilities
:members:
        :undoc-members:
        :show-inheritance: